
# CBD-KEY-SIMON - The COMBAT integrated dataset

Release date: 06/10/2020
Contact email: adriana.tomic@paediatrics.ox.ac.uk

## How to use this readme
This is a dataset description document which describes generated files from COMBAT integrated analysis. The file is written using [Markdown language](https://en.wikipedia.org/wiki/Markdown). To properly render and view this file please use any of the markdown viewers eg. [this online viewer](https://stackedit.io/).

## File list
* **CBD-MDA-00001.csv**
    * Samples coverage across assays
* **first_sample_across_assays_1.7z**
    * Merged COMBAT dataset of first samples that are shared between mass spectormetry and luminex datasets. The [7zip](https://www.7-zip.org/) file contains full dataset file and an example file, containing only first 20 samples.
        - first_sample_across_assays_1.csv
        - first_sample_across_assays_1.example.csv
* **first_sample_across_assays_2.7z**
    * Merged COMBAT dataset of first samples that are shared between CyTOF, FACS, GSA, RNA_seq and CITE-seq datasets. The [7zip](https://www.7-zip.org/) file contains full dataset file and an example file, containing only first 20 samples.
        - first_sample_across_assays_2.csv
        - first_sample_across_assays_2.example.csv
* **first_sample_across_assays_2_no_cite_seq.7z**
    * Merged COMBAT dataset of first samples that are shared between CyTOF, FACS, GSA and RNA_seq datasets. The [7zip](https://www.7-zip.org/) file contains full dataset file and an example file, containing only first 20 samples.
        - first_sample_across_assays_2_no_cite_seq.csv
        - first_sample_across_assays_2_no_cite_seq.example.csv
* **first_sample_across_assays_3.7z**
    * Merged COMBAT dataset of first samples that are shared between mass spectrometry, luminex, CyTOF, FACS, GSA, RNA_seq and CITE-seq datasets. The [7zip](https://www.7-zip.org/) file contains full dataset file and an example file, containing only first 20 samples.
        - first_sample_across_assays_3.csv
        - first_sample_across_assays_3.example.csv
* **first_sample_across_assays_3_no_cite_seq.7z**
    * Merged COMBAT dataset of first samples that are shared between mass spectrometry, luminex, CyTOF, FACS, GSA and RNA_seq datasets. The [7zip](https://www.7-zip.org/) file contains full dataset file and an example file, containing only first 20 samples.
        - first_sample_across_assays_3_no_cite_seq.csv
        - first_sample_across_assays_3_no_cite_seq.example.csv

## About

The `COMBAT` dataset represents a fully integrated biomedical measurements across 8 modalities from 268 individuals enrolled in the COVID-19 Multi-Omics Blood Atlas (`COMBAT`) project.
In total, the `COMBAT` dataset contains information on more than million parameters measured using flow cytometry, mass cytometry (cytometry by time-of-flight, CyTOF), Cellular Indexing of Transcriptomes and Epitopes by Sequencing (CITE-seq), global screening array (gsa), bulk RNA sequencing (RNAseq), luminex, mass spectroscopy and a basic set of clinical data. The following datasets were used for generation of the integrated `COMBAT` dataset: 
- CBD-KEY-CLINVAR
- CBD-KEY-CITESEQ-GEX
- CBD-KEY-CYTOF
- CBD-KEY-FACS
- CBD-KEY-LUMINEX
- CBD-KEY-PROTEOMICS
- CBD-KEY-RNASEQ-WB

## Dataset specification

### CBD-MDA-00001

The `COMBAT` dataset (CBD-MDA-00001) contains 29 columns and 428 rows. Each row represents one sample, while columns are described below.

- **Column Name(s)**: cytof, facs, gsa, iron, luminex, mass_spec, rna_seq, cite_seq
**Description**: Is sample analyzed in specific assay?
**Values**: 1 - yes, 0 - no

- **Column Name(s)**: first_sample_across_assays_1, first_sample_across_assays_2, first_sample_across_assays_3
**Description**:  Ordering of samples shared between specific assays based on Days_symptom_to_sample column.
**Values**: 999 - not present within assays, 1,2,3, 4 - ordering 
     - Assay Specification:
         - *first_sample_across_assays_1*
         In between assays: luminex, mass_spec
         - *first_sample_across_assays_2*
         In between assays: cytof, facs, rna_seq, gsa
        - *first_sample_across_assays_3*
        In between assays: luminex, mass_spec, cytof, facs, rna_seq, gsa

- **Column Name(s)**: day_sampling_from_max_disease
**Description**: Day when sample was obtained from day of maximum disease
**Values**: Calculated as: days_symptoms_max - Days_symptom_to_sample

- **Column Name(s)**: disease 
**Description**: Samples acquired in the convalescence are labelled as recovered, while samples acquired during the disease are labelled as ongoing.
**Values**: 1 - recovered, 2 - ongoing, 3 - ""

- **Column Name(s)**: hospitalized
**Description**: Samples from COVID patients (COVID health-care workers and COVID hospitalized patients) separated based on hospitalization status.
**Values**: 1 - no (non-hospitalized), 2 - yes (hospitalized), 3 - ""

- **Column Name(s)**: oxygenation
**Description**: 'Oxygen Status Max' column merged into two values: normal and abnormal (depleted, hypoxic)
**Values**: 1 - normal, 2 - abnormal

- **Column Name(s)**: sampling
**Description**: Disease phase divided in early and late based on criteria found in Days_symptom_to_sample column. Values between 1-10 are classified as early and >=11 as late.
**Values**: 1 - early, 2 - late

- **Column Name(s)**: sampling_from_max_disease
**Description**: Classification of 'day_sampling_from_max_disease' column. All values below 0 are calsified as after and other as before.
**Values**: 1 - before, 2 - after

- **Column Name(s)**: source_disease
**Description**: Categorization of patients into COVID ("covid_sev", "covid_crit", "covid_mild") or sepsis based on the Source column.
**Values**: 1 - covid, 2 - sepsis, NA - others

- **Column Name(s)**: ventilation
**Description**: 'Ventilation Status Max' column merged into two values: room air is 1 and others 2
**Values**: 1 - no, 2 - yes

- **Column Name(s)**: disease_progress
**Description**: Calculation of the disease progress for each donor where longitudinal samples are available. Disease progress is calculated from 'severity at sample' column. Values are assigned based on comparison between current and previous sample. 
**Values**: degeneration, recovery, no_change, NA
> If severity of previous sample is 'mild', while for the current sample is 'severe', we calculate disease progress for current sample as 'degeneration' since the severity increased. 'Recovery' is given if the severity of the disease improved in comparison to previous sample and 'no_change' is given if the disease progress is the same, while NA is given if no longitudinal samples are present.
> 

Remaining **8 columns** are merged from the **clinical dataset file** and include:
* COMBAT_ID
* ATAC_sample_ID
* COMBAT_antibody_data_ID
* COMBAT_Luminex_sample_ID
* COMBAT_proteomics_sample_ID
* CyTOF_sample_ID
* RNASeq_sample_ID
* scRNASeq_sample_ID
